@@ -1,4 +1,4 @@
-# version  : 2.01 - September 2020
+# version  : 2.02 - November 2020
 # author   : Thierry LE GALL 
 # contact  : facila@gmx.fr
 
@@ -217,7 +217,7 @@ sub sort {
     foreach ( split/;/,$list ) {
        return if &error('ip',$_);
        $list{sprintf "%03d%03d%03d%03d", split/\./} = $_ }
-    foreach ( sort { $a <=> $b } keys %list ) { $result .= "$list{$_} - $_ -\n" }
+    foreach ( sort { $a <=> $b } keys %list ) { $result .= "$list{$_}\n" }
     return $result }
   
 sub summary {
@@ -591,7 +591,7 @@ __END__
 
 =head1 VERSION AND AUTHOR
 
- Version  : v2.01 - September 2020
+ Version  : v2.02 - November 2020
  Author   : Thierry LE GALL
  Contact  : facila@gmx.fr
 
